@@ -1,4 +1,4 @@
-__version__ = "1.0.99"
+__version__ = "1.1.3"
 
 import kappadata.caching
 import kappadata.common
@@ -21,6 +21,7 @@ from .collators.kd_mix_collator import KDMixCollator
 from .collators.pad_sequences_collator import PadSequencesCollator
 # common
 from .common.transforms.norm.kd_cifar10_norm import KDCifar10Norm
+from .common.transforms.norm.kd_cifar100_norm import KDCifar100Norm
 from .common.transforms.norm.kd_image_net_norm import KDImageNetNorm
 # copying
 from .copying import (
@@ -33,6 +34,8 @@ from .datasets.kd_concat_dataset import KDConcatDataset
 from .datasets.kd_dataset import KDDataset
 from .datasets.kd_subset import KDSubset
 from .datasets.kd_wrapper import KDWrapper
+# factory
+from .factory import object_to_transform
 # transforms base
 from .transforms.base import KDComposeTransform
 from .transforms.base import KDIdentityTransform
@@ -64,14 +67,15 @@ from .transforms.patchwise_shuffle import PatchwiseShuffle
 from .transforms.save_state_to_context_transform import SaveStateToContextTransform
 from .transforms.unpatchify_image import UnpatchifyImage
 # utils
-from .utils.is_deterministic_transform import (
-    is_deterministic_transform,
-    IsDeterministicTransformResult,
-    has_stochastic_transform_with_seed,
-    is_randomly_seeded_transform,
+from .utils.transform_utils import (
+    flatten_transform,
+    get_denorm_transform,
+    get_norm_transform,
+    get_x_transform,
 )
 # wrappers.dataset_wrappers
 from .wrappers.dataset_wrappers.class_filter_wrapper import ClassFilterWrapper
+from .wrappers.dataset_wrappers.classwise_subset_wrapper import ClasswiseSubsetWrapper
 from .wrappers.dataset_wrappers.oversampling_wrapper import OversamplingWrapper
 from .wrappers.dataset_wrappers.percent_filter_wrapper import PercentFilterWrapper
 from .wrappers.dataset_wrappers.repeat_wrapper import RepeatWrapper
@@ -80,17 +84,8 @@ from .wrappers.dataset_wrappers.subset_wrapper import SubsetWrapper
 from .wrappers.mode_wrapper import ModeWrapper
 # wrappers.sample_wrappers
 from .wrappers.sample_wrappers.kd_mix_wrapper import KDMixWrapper
-from .wrappers.sample_wrappers.label_smoothing_wrapper import LabelSmoothingWrapper
 from .wrappers.sample_wrappers.kd_multi_view_wrapper import KDMultiViewWrapper
+from .wrappers.sample_wrappers.label_smoothing_wrapper import LabelSmoothingWrapper
 from .wrappers.sample_wrappers.one_hot_wrapper import OneHotWrapper
 from .wrappers.sample_wrappers.x_transform_wrapper import XTransformWrapper
 from .wrappers.torch_wrapper import TorchWrapper
-# utils
-from .utils.transform_utils import (
-    flatten_transform,
-    get_denorm_transform,
-    get_norm_transform,
-    get_x_transform,
-)
-# factory
-from .factory import object_to_transform
\ No newline at end of file
